Meu ambiente de trabalho em 7 itens | Andrews Medina

## Meu ambiente de trabalho em 7 itens

escrito em 27/01/2011

O @franciscosouza me convocou para listar 7 ítens do meu ambiente de trabalho. Então, lá vamos nós...

### 1) git + github

O git é uma ótima ferramenta para controle de versão, rápido e distribuído. Já o github é mais que um repósitorio para projetos opensource. É uma rede social para desenvolvedores, onde você pode seguir desenvolvedores e projetos. Ele também simplifica e ajuda a desburocratização da colaboração com o software livre, facilitando a colaboração.

### 2) textmate

O meu editor favorito é o textmate. Ele é simples, tem syntax highlighting e é facil fazer macros e plugins para ele.

### 3) macbook + mac os

Para mim o macbook e o mac os é a melhor harmonia entre o software e o hardware. =)

O mac os é muito agradável, fácil de usar, não é necessário perder tempo instalando drivers e etc, e é unix o que o torna bem poderoso como ambiente de desenvolvimento.

Ah, e a bateria dura bastante tempo.

### 4) homebrew, iterm2

Como terminal eu tenho utilizado o iterm2 tenho gostado. E para instalar pacotes utilizo homebrew.

### 5) pip + virtualenv + virtualenvwrapper

Atualmente utilizo várias linguagens de programação, mas a que mais utilizo (no momento) é Python.

Para desenvolver em Python, utilizo pip para instalação de pacotes, virtualenv e virtualenvwrapper, para trabalhar em ambientes limpos e isolados pro projeto. Fazendo com que um ambiente utilizado pelo projeto X não precise ter instalado as dependências do projeto Y.

### 6) TeamCity Continuous Integration Server

Para mim um código não testado não existe. E para monitorar meus projetos e saber se seus testes estão passando eu utilizo o TeamCity com um plugin para chrome, que mostra no chrome se o build está passando ou está quebrado.

### 7) monitor + teclado sem fio + mouse

Junto com o macbook eu utilizo um monitor, um teclado sem fio da apple e um mouse da microsoft.

### Passo a bola para:

- Igor Sobreira (@igorsobreira)
- Tales (Tarsis Azevedo) (@tarsisazevedo)
- Thiago Hiromi (@badchoosed)
- Luciano Ramalho (@luciano)
- Douglas Miranda (@douglaswebdev)